@@ -12,25 +12,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """
-IBMQ Device
-===========
-
-**Module name:** :mod:`pennylane_qiskit.ibmq`
-
-.. currentmodule:: pennylane_qiskit.ibmq
-
 This module contains the :class:`~.IBMQDevice` class, a PennyLane device that allows
 evaluation and differentiation of IBM Q's Quantum Processing Units (QPUs)
 using PennyLane.
-
-Classes
--------
-
-.. autosummary::
-   IBMQDevice
-
-Code details
-~~~~~~~~~~~~
 """
 import os
 
@@ -52,7 +36,10 @@ class IBMQDevice(QiskitDevice):
     there is a credit system to limit access to the quantum devices.
 
     Args:
-        wires (int): The number of qubits of the device
+        wires (int or Iterable[Number, str]]): Number of subsystems represented by the device,
+            or iterable that contains unique labels for the subsystems as numbers (i.e., ``[-1, 0, 2]``)
+            or strings (``['ancilla', 'q1', 'q2']``). Note that for some backends, the number
+            of wires has to match the number of qubits accessible.
         provider (Provider): The IBM Q provider you wish to use. If not provided,
             then the default provider returned by ``IBMQ.get_provider()`` is used.
         backend (str): the desired provider backend
@@ -71,13 +58,13 @@ class IBMQDevice(QiskitDevice):
     short_name = "qiskit.ibmq"
 
     def __init__(self, wires, provider=None, backend="ibmq_qasm_simulator", shots=1024, **kwargs):
-        token = os.getenv("IBMQX_TOKEN") or kwargs.get("ibmqx_token", None)
-        url = os.getenv("IBMQX_URL") or kwargs.get("ibmqx_url", None)
+        token = kwargs.get("ibmqx_token", None) or os.getenv("IBMQX_TOKEN")
+        url = kwargs.get("ibmqx_url", None) or os.getenv("IBMQX_URL")
 
         # Specify a single hub, group and project
-        hub = kwargs.get("hub", 'ibm-q')
-        group = kwargs.get("group", 'open')
-        project = kwargs.get("project", 'main')
+        hub = kwargs.get("hub", "ibm-q")
+        group = kwargs.get("group", "open")
+        project = kwargs.get("project", "main")
 
         if token is not None:
             # token was provided by the user, so attempt to enable an
@@ -108,3 +95,24 @@ class IBMQDevice(QiskitDevice):
         p = provider or IBMQ.get_provider(hub=hub, group=group, project=project)
 
         super().__init__(wires=wires, provider=p, backend=backend, shots=shots, **kwargs)
+
+    def batch_execute(self, circuits):
+        res = super().batch_execute(circuits)
+        if self.tracker.active:
+            self._track_run()
+        return res
+
+    def _track_run(self):
+        """Provide runtime information."""
+
+        time_per_step = self._current_job.time_per_step()
+        job_time = {
+            "creating": (time_per_step["CREATED"] - time_per_step["CREATING"]).total_seconds(),
+            "validating": (
+                time_per_step["VALIDATED"] - time_per_step["VALIDATING"]
+            ).total_seconds(),
+            "queued": (time_per_step["RUNNING"] - time_per_step["QUEUED"]).total_seconds(),
+            "running": (time_per_step["COMPLETED"] - time_per_step["RUNNING"]).total_seconds(),
+        }
+        self.tracker.update(job_time=job_time)
+        self.tracker.record()
